# Open Trip Plan

Open Trip Plan allows to plan a trip by adding markers on a map (using the Folium library to display an OpenStreetMap map) associated with a note.

Open Trip Plan is on PyPi. To install it, run:

```sh
pip install opentripplan
```

Tested on Linux. Should work on any platform.
